@@ -849,14 +849,22 @@ basep_widget_focus_in_event (GtkWidget     *widget,
 static BasePWidget *
 find_non_drawer_parent_panel (BasePWidget *basep)
 {
-	BasePWidget *retval;
+	BasePWidget *retval = NULL;
 	Drawer      *drawer;
+	GtkWidget   *panel_parent;
 
 	g_assert (DRAWER_IS_WIDGET (basep));
 
 	drawer = drawer_widget_get_drawer (DRAWER_WIDGET (basep));
+	if (!drawer)
+		return NULL;
 
-	retval = BASEP_WIDGET (PANEL_WIDGET (drawer->button->parent)->panel_parent);
+	panel_parent = PANEL_WIDGET (drawer->button->parent)->panel_parent;
+
+	if (BASEP_IS_WIDGET (panel_parent))
+		retval = BASEP_WIDGET (panel_parent);
+	else if (FOOBAR_IS_WIDGET (panel_parent))
+		return NULL;
 
 	if (DRAWER_IS_WIDGET (retval))
 		retval = find_non_drawer_parent_panel (retval);
@@ -876,7 +884,8 @@ basep_leave_notify (GtkWidget *widget,
 	if (DRAWER_IS_WIDGET (basep))
 		basep = find_non_drawer_parent_panel (basep);
 	
-	basep_widget_queue_autohide (basep);
+	if (basep)
+		basep_widget_queue_autohide (basep);
 
 	if (GTK_WIDGET_CLASS (basep_widget_parent_class)->leave_notify_event)
 		return GTK_WIDGET_CLASS (basep_widget_parent_class)->leave_notify_event (widget, event);
@@ -1764,6 +1773,8 @@ basep_widget_construct (const char *panel_id,
 
 	/* setup the hide buttons stuff according to state */
 	setup_hidebuttons (basep);
+
+	basep_update_frame (basep);
 	       
 	if (klass->get_pos)
 		klass->get_pos (basep, &x, &y, 
