@@ -212,6 +212,8 @@ nibble_on_file (const char *file)
 	mode_t old_mask;
 
 	if (access (file, F_OK) == 0) {
+		int response;
+
 		dialog = gtk_message_dialog_new
 			(GTK_WINDOW (toplevel),
 			 0 /* flags */,
@@ -219,13 +221,15 @@ nibble_on_file (const char *file)
 			 GTK_BUTTONS_YES_NO,
 			 _("File %s already exists. Overwrite?"),
 			 file);
-		if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES) {
-			gtk_widget_destroy (dialog);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+
+		if (response != GTK_RESPONSE_YES)
 			return NULL;
-		}
 	}
 
-	old_mask = umask(077);
+	old_mask = umask(022);
 
 	fp = fopen (file, "w");
 	if (fp == NULL) {
@@ -791,13 +795,17 @@ on_ok_button_clicked (GtkWidget *widget,
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button))) {
 		GtkWidget *entry;
 		GtkWidget *fileentry;
+		const gchar *tmp;
 		entry = glade_xml_get_widget (xml, "save_entry");
 		fileentry = glade_xml_get_widget (xml, "save_fileentry");
-		if (gimme_file (gtk_entry_get_text (GTK_ENTRY (entry)))) {
+ 		tmp = gtk_entry_get_text (GTK_ENTRY (entry));
+ 		file = g_filename_from_utf8 (tmp, -1, NULL, NULL, NULL);
+ 		if (gimme_file (file)) {
 			gnome_entry_prepend_history (GNOME_ENTRY (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (fileentry))),
 						     TRUE, gtk_entry_get_text (GTK_ENTRY (entry)));
 			gtk_main_quit ();
 		}
+		g_free (file);
 		setup_busy (FALSE);
 		return;
 	}
