@@ -218,27 +218,11 @@ launcher_properties_destroy (Launcher *launcher)
 		gtk_widget_destroy (dialog);
 }
 
-static void
-icon_theme_changed_cb (GnomeIconTheme *icon_theme,
-		       Launcher        *launcher)
-{
-	const char *icon;
-
-	g_return_if_fail (launcher != NULL);
-
-	icon = gnome_desktop_item_get_string (
-			launcher->ditem, GNOME_DESKTOP_ITEM_ICON);
-
-	button_widget_set_pixmap (BUTTON_WIDGET (launcher->button), icon);
-}
-
 static void
 free_launcher (gpointer data)
 {
 	Launcher *launcher = data;
 
-	g_signal_handler_disconnect (panel_icon_theme, launcher->icon_changed_signal);
-
 	launchers_to_hoard = g_slist_remove (launchers_to_hoard, launcher);
 
 	gnome_desktop_item_unref (launcher->ditem);
@@ -483,6 +467,7 @@ setup_button (Launcher *launcher)
 	const char *docpath;
 	char *str;
 	const char *icon;
+	char *unescaped_str;
 	
 	g_return_if_fail (launcher != NULL);
 
@@ -496,23 +481,22 @@ setup_button (Launcher *launcher)
 		str = g_strdup_printf ("%s\n%s", name, comment);
 	else
 		str = g_strdup (name);
+
+	unescaped_str = gnome_vfs_unescape_string (str, NULL);
 	gtk_tooltips_set_tip (panel_tooltips, launcher->button,
-			      str, NULL);
+			      unescaped_str, NULL);
 
 	/* Setup accessible name */
-	panel_set_atk_name_desc (launcher->button, str, NULL);
+	panel_set_atk_name_desc (launcher->button, unescaped_str, NULL);
 
 	g_free (str);
+	g_free (unescaped_str);
 
 	/* Setup icon */
 	icon = gnome_desktop_item_get_string (launcher->ditem,
 					      GNOME_DESKTOP_ITEM_ICON);
 	button_widget_set_pixmap (BUTTON_WIDGET (launcher->button), icon);
 
-	launcher->icon_changed_signal =
-			g_signal_connect (panel_icon_theme, "changed",
-					  G_CALLBACK (icon_theme_changed_cb), launcher);
-
 	/* Setup help */
 	docpath = gnome_desktop_item_get_string (launcher->ditem,
 						 "X-GNOME-DocPath");
@@ -837,6 +821,10 @@ really_add_launcher (GtkWidget *dialog, int response, gpointer data)
 		return;
 	}
 
+	panel->create_launcher_dialog_list = 
+					g_slist_remove (panel->create_launcher_dialog_list, 
+							dialog);
+
 	gtk_widget_destroy (dialog);
 }
 
@@ -867,6 +855,10 @@ ask_about_launcher (const char  *file,
 			    GTK_WIDGET (dee),
 			    TRUE, TRUE, GNOME_PAD_SMALL);
 
+	panel->create_launcher_dialog_list = 
+					g_slist_append (panel->create_launcher_dialog_list,
+							dialog);
+
 	ditem = gnome_desktop_item_new ();
 	gnome_desktop_item_set_string (ditem, GNOME_DESKTOP_ITEM_EXEC, file);
 	gnome_desktop_item_set_entry_type (ditem, GNOME_DESKTOP_ITEM_TYPE_APPLICATION);
