@@ -942,7 +942,7 @@ panel_widget_switch_move (PanelWidget *panel, AppletData *ad, int moveby)
 		while (ad->pos < finalpos) {
 			pos = panel_widget_get_right_switch_pos (panel, list);
 			if (pos + ad->min_cells > panel->size ||
-			    abs (pos - finalpos) > abs (ad->pos - finalpos))
+			    abs (pos - finalpos) >= abs (ad->pos - finalpos))
 				break;
 			panel_widget_switch_applet_right (panel, list);
 		}
@@ -954,7 +954,7 @@ panel_widget_switch_move (PanelWidget *panel, AppletData *ad, int moveby)
 	} else {
 		while (ad->pos > finalpos) {
 			pos = panel_widget_get_left_switch_pos (panel, list);
-			if (pos < 0 || abs (pos - finalpos) > abs (ad->pos - finalpos))
+			if (pos < 0 || abs (pos - finalpos) >= abs (ad->pos - finalpos))
 				break;
 			panel_widget_switch_applet_left (panel, list);
 		}
@@ -1416,6 +1416,12 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	return FALSE;
 }
 
+static void
+emit_background_changed (PanelWidget *panel_widget)
+{
+	g_signal_emit (panel_widget, panel_widget_signals [BACK_CHANGE_SIGNAL], 0);
+}
+
 void
 panel_widget_set_back_pixmap (PanelWidget *panel,
 			      const char  *image_path)
@@ -1423,8 +1429,8 @@ panel_widget_set_back_pixmap (PanelWidget *panel,
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
 	g_return_if_fail (image_path != NULL);
 
-	panel_background_set_image (
-		&panel->background, image_path, FALSE, FALSE, FALSE);
+	if (panel_background_set_image (&panel->background, image_path, FALSE, FALSE, FALSE))
+		emit_background_changed (panel);
 
 	gtk_widget_queue_draw (GTK_WIDGET (panel));
 }
@@ -1436,7 +1442,8 @@ panel_widget_set_back_color (PanelWidget *panel,
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
 	g_return_if_fail (color != NULL);
 
-	panel_background_set_color (&panel->background, color);
+	if (panel_background_set_color (&panel->background, color))
+		emit_background_changed (panel);
 
 	gtk_widget_queue_draw (GTK_WIDGET (panel));
 }
@@ -1624,6 +1631,8 @@ panel_widget_instance_init (PanelWidget *panel)
 	panel->master_widget = NULL;
 	panel->drop_widget   = widget;
 	panel->inhibit_draw  = FALSE;
+	panel->delete_dialog = NULL;
+	panel->create_launcher_dialog_list = NULL;
 
 	panel_background_init (&panel->background);
 
@@ -1654,9 +1663,10 @@ panel_widget_new (const char          *panel_id,
 	else
 		panel->unique_id = g_strdup (panel_id);
 
-	panel_background_set (
+	if (panel_background_set (
 		&panel->background, back_type, back_color, back_pixmap,
-		fit_pixmap_bg, stretch_pixmap_bg, rotate_pixmap_bg);
+		fit_pixmap_bg, stretch_pixmap_bg, rotate_pixmap_bg))
+		emit_background_changed (panel);
 
 	panel->orient = orient;
 	panel->sz = sz;
@@ -2514,13 +2524,8 @@ panel_widget_change_params(PanelWidget         *panel,
 	change_back = panel_background_set (
 			&panel->background, back_type, back_color, pixmap,
 			fit_pixmap_bg, stretch_pixmap_bg, rotate_pixmap_bg);
-	if (change_back) {
-		panel_background_realized (
-			&panel->background, GTK_WIDGET (panel)->window);
-		
-		g_signal_emit (
-			panel, panel_widget_signals [BACK_CHANGE_SIGNAL], 0);
-	}
+	if (change_back)
+		emit_background_changed (panel);
 
 	/* inhibit draws until we resize */
 	panel->inhibit_draw = TRUE;
@@ -2699,3 +2704,26 @@ panel_widget_get_applet_orient (PanelWidget *panel)
 
 	return basep_widget_get_applet_orient (BASEP_WIDGET (panel->panel_parent));
 }
+
+void
+panel_widget_remove_drawers (PanelWidget *panel_widget)
+{
+	GList *l;
+
+	for (l = panel_widget->applet_list; l ; l = l->next) {
+
+		AppletData* applet_data = l->data;
+		AppletInfo* info = g_object_get_data (
+						G_OBJECT (applet_data->applet), "applet_info");
+
+		if (info && info->type == APPLET_DRAWER) {
+			Drawer *drawer = (Drawer *) info->data;
+			BasePWidget* drawer_widget = (BASEP_WIDGET (drawer->drawer));
+
+			panel_widget_remove_drawers (PANEL_WIDGET(drawer_widget->panel));
+
+			panel_remove_from_gconf(PANEL_WIDGET(drawer_widget->panel));
+		}
+	}
+
+}
