@@ -533,6 +533,19 @@ panel_remove_applets (PanelWidget *panel)
 	}
 }
 
+static void
+panel_remove_open_create_launcher_dialogs (PanelWidget *panel)
+{
+	GSList *l;
+
+	for (l = panel->create_launcher_dialog_list; l ; l = l->next) {
+		GtkWidget *dialog = l->data;
+
+		if (GTK_IS_WIDGET (dialog))
+			gtk_widget_destroy (dialog);
+	}
+}
+
 static void
 panel_destroy (GtkWidget *widget, gpointer data)
 {
@@ -546,6 +559,8 @@ panel_destroy (GtkWidget *widget, gpointer data)
 
 	panel_remove_applets (panel);
 		
+	panel_remove_open_create_launcher_dialogs (panel);
+
 	kill_config_dialog (widget);
 
 	if ((BASEP_IS_WIDGET (widget) && !DRAWER_IS_WIDGET (widget)) ||
@@ -2349,7 +2364,7 @@ panel_load_panel_from_gconf (const char *profile,
 	}
 
 	tmp_str = panel_get_string (profile, panel_id, "panel_background_color", NULL);
-	if (!tmp_str || !tmp_str [0]) {
+	if (tmp_str && tmp_str [0]) {
 		gdk_color_parse (tmp_str, &gdkcolor);
 		back_color.gdk = gdkcolor;
 	}
@@ -2796,3 +2811,122 @@ panel_remove_from_gconf (PanelWidget *panel)
 	if (new_panels)
 		panel_g_slist_deep_free (new_panels);
 }
+
+static void
+panel_delete_without_query (PanelWidget *panel_widget)
+{
+	GtkWidget * panel;
+
+	panel = GTK_WIDGET (panel_widget->panel_parent);
+
+	/* Destroy the drawers button before destroying the drawer */
+	if (DRAWER_IS_WIDGET (panel)) {         
+
+		if (panel_widget && panel_widget->master_widget) {
+			AppletInfo *info;
+			Drawer *drawer;
+
+			panel_widget_remove_drawers (panel_widget);
+
+			info = g_object_get_data (
+					G_OBJECT (panel_widget->master_widget),
+					"applet_info");
+
+			drawer = (Drawer *) info->data;
+
+			g_signal_handler_disconnect (drawer->button,
+						     drawer->focus_out_handler);
+
+			drawer->drawer = NULL;
+
+			panel_applet_clean (info, TRUE);
+
+			g_assert (panel_widget->master_widget == NULL);
+		}
+	} else 
+		panel_widget_remove_drawers (panel_widget);
+
+	panel_remove_from_gconf (PANEL_WIDGET (BASEP_WIDGET (panel)->panel));
+
+	gtk_widget_destroy (panel);
+
+} 
+
+static void
+remove_panel_accept (GtkWidget *w,
+		     int        response,
+		     GtkWidget *panel)
+{
+	PanelWidget *panel_widget;
+
+	panel_widget = PANEL_WIDGET (BASEP_WIDGET (panel)->panel);
+
+	if (response == GTK_RESPONSE_OK) {
+		panel_push_window_busy (w);
+		panel_delete_without_query(panel_widget);
+		panel_pop_window_busy (w);
+	} else 
+		panel_widget->delete_dialog = NULL;
+
+	gtk_widget_destroy (w);
+}
+
+static void
+panel_delete_query (PanelWidget *panel_widget)
+{
+	GtkWidget   *dialog;
+	GtkWidget   *panel;
+
+	panel = panel_widget->panel_parent;
+
+	if (panel_widget->delete_dialog) {
+		gtk_window_present (GTK_WINDOW (panel_widget->delete_dialog));
+		return;
+	}
+
+	dialog = gtk_message_dialog_new (
+			GTK_WINDOW (panel_widget->panel_parent), 
+			GTK_DIALOG_MODAL /* flags */,
+			GTK_MESSAGE_QUESTION,
+			GTK_BUTTONS_NONE,
+			_("When a panel is deleted, the panel "
+			"and its\n settings are lost. "
+			"Delete this panel?"));
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				GTK_STOCK_DELETE, GTK_RESPONSE_OK,
+				NULL);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Delete Panel"));
+
+	gtk_window_set_wmclass (GTK_WINDOW (dialog),
+				"panel_remove_query", "Panel");
+	gtk_window_set_screen (GTK_WINDOW (dialog),
+			       gtk_window_get_screen (GTK_WINDOW (panel)));
+
+	gtk_window_set_position (GTK_WINDOW (dialog),GTK_WIN_POS_CENTER);
+
+	panel_widget->delete_dialog = dialog;
+
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (remove_panel_accept),
+			  panel);
+	panel_signal_connect_object_while_alive (
+			G_OBJECT (panel), "destroy",
+			G_CALLBACK (gtk_widget_destroy),
+			G_OBJECT (dialog));
+	gtk_widget_show_all (dialog);
+}
+
+void
+panel_delete (PanelWidget *panel_widget)
+{
+	if (!global_config.confirm_panel_remove ||
+	     g_list_length(panel_widget->applet_list) == 0) {
+		panel_delete_without_query (panel_widget);
+		return;
+	}
+
+	panel_delete_query (panel_widget);
+}
