@@ -275,7 +275,7 @@ sliding_pos_get_pos (BasePWidget *basep, int *x, int *y,
 }
 
 GtkWidget *
-sliding_widget_new (gchar *panel_id,
+sliding_widget_new (const char *panel_id,
 		    int screen,
 		    int monitor,
 		    SlidingAnchor anchor,
@@ -287,7 +287,7 @@ sliding_widget_new (gchar *panel_id,
 		    gboolean hidebuttons_enabled,
 		    gboolean hidebutton_pixmaps_enabled,
 		    PanelBackgroundType back_type,
-		    char *back_pixmap,
+		    const char *back_pixmap,
 		    gboolean fit_pixmap_bg,
 		    gboolean stretch_pixmap_bg,
 		    gboolean rotate_pixmap_bg,
